@@ -148,7 +148,7 @@ function(phe, geno, map, K=NULL, nPC.GLM=NULL, nPC.MLM=NULL, nPC.FarmCPU=NULL,
     m <- nrow(geno)
     n <- ncol(geno)
     logging.log(paste("Input data has", n, "individuals,", m, "markers"), "\n", verbose = verbose)
-    logging.log("Phenotype: ", colnames(phe)[2],  verbose = verbose)
+    logging.log("Phenotype:", colnames(phe)[2], "\n", verbose = verbose)
     
     #initial results
     glm.results <- NULL
@@ -194,39 +194,61 @@ function(phe, geno, map, K=NULL, nPC.GLM=NULL, nPC.MLM=NULL, nPC.FarmCPU=NULL,
         #CV for GLM
         if(glm.run){
             if(!is.null(CV.GLM)){
+                logging.log("Number of provided covariates of GLM:", ncol(CV.GLM), "\n", verbose = verbose)
                 if(!is.null(nPC.GLM)){
+                    logging.log("Number of PCs included:", nPC.GLM, "\n", verbose = verbose)
                     CV.GLM <- cbind(ipca[,1:nPC.GLM], CV.GLM)
                 }
             }else{
-                if(!is.null(nPC.GLM))   CV.GLM <- ipca[,1:nPC.GLM]
+                if(!is.null(nPC.GLM)){logging.log("Number of PCs included in GLM:", nPC.GLM, "\n", verbose = verbose); CV.GLM <- ipca[,1:nPC.GLM]}
             }
         }
         
         #CV for MLM
         if(mlm.run){
             if(!is.null(CV.MLM)){
+                logging.log("Number of provided covariates of MLM:", ncol(CV.MLM), "\n", verbose = verbose)
                 if(!is.null(nPC.MLM)){
+                    logging.log("Number of PCs included:", nPC.MLM, "\n", verbose = verbose)
                     CV.MLM <- cbind(ipca[,1:nPC.MLM], CV.MLM)
                 }
             }else{
-                if(!is.null(nPC.MLM))   CV.MLM <- ipca[,1:nPC.MLM]
+                if(!is.null(nPC.MLM)){logging.log("Number of PCs included in MLM:", nPC.MLM, "\n", verbose = verbose); CV.MLM <- ipca[,1:nPC.MLM]}
             }
         }
         
         #CV for FarmCPU
         if(farmcpu.run){
             if(!is.null(CV.FarmCPU)){
+                logging.log("Number of provided covariates of FarmCPU:", ncol(CV.FarmCPU), "\n", verbose = verbose)
                 if(!is.null(nPC.FarmCPU)){
+                    logging.log("Number of PCs included:", nPC.FarmCPU, "\n", verbose = verbose)
                     CV.FarmCPU <- cbind(ipca[,1:nPC.FarmCPU], CV.FarmCPU)
                 }
             }else{
-                if(!is.null(nPC.FarmCPU))   CV.FarmCPU <- ipca[,1:nPC.FarmCPU]
+                if(!is.null(nPC.FarmCPU)){logging.log("Number of PCs included in FarmCPU:", nPC.FarmCPU, "\n", verbose = verbose); CV.FarmCPU <- ipca[,1:nPC.FarmCPU]}
             }
         }  
+    }else{
+        if(glm.run){
+            if(!is.null(CV.GLM)){
+                logging.log("Number of provided covariates of GLM:", ncol(CV.GLM), "\n", verbose = verbose)
+            }
+        }
+        if(mlm.run){
+            if(!is.null(CV.MLM)){
+                logging.log("Number of provided covariates of MLM:", ncol(CV.MLM), "\n", verbose = verbose)
+            }
+        }
+        if(farmcpu.run){
+            if(!is.null(CV.FarmCPU)){
+                logging.log("Number of provided covariates of FarmCPU:", ncol(CV.FarmCPU), "\n", verbose = verbose)
+            }
+        }
     }
   
     #GWAS
-    logging.log("|------------------------GWAS Start------------------------|", "\n", verbose = verbose)
+    logging.log("-------------------------GWAS Start-------------------------", "\n", verbose = verbose)
     if(glm.run){
         logging.log("General Linear Model (GLM) Start...", "\n", verbose = verbose)
         glm.results <- MVP.GLM(phe=phe, geno=geno, CV=CV.GLM, cpu=ncpus, bar=bar, verbose = verbose);gc()
@@ -310,7 +332,7 @@ function(phe, geno, map, K=NULL, nPC.GLM=NULL, nPC.MLM=NULL, nPC.FarmCPU=NULL,
         }
     }
     if(file.output){
-        logging.log("|--------------------Visualization Start-------------------|", "\n", verbose = verbose)
+        logging.log("---------------------Visualization Start-------------------", "\n", verbose = verbose)
         logging.log("Phenotype distribution Plotting", "\n", verbose = verbose)
         MVP.Hist(memo=memo, outpath=outpath, file.output=file.output, phe=phe, file.type=file.type, col=col, dpi=dpi)
         #plot3D <- !is(try(library("rgl"),silent=TRUE), "try-error")
